@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2003-2009 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2003-2018 HP Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,12 +35,12 @@ USAGE_FLAG_SUPRESS_G_DEBUG_FLAG = 0x02
 USAGE_FLAG_FILE_ARGS = 0x04
 
 
-
+uiscan=False
 class Module(object):
     def __init__(self, mod, title, version, doc,
                  usage_data=None, avail_modes=None,
                  supported_ui_toolkits=None,
-                 run_as_root_ok=False, quiet=False):
+                 run_as_root_ok=False, quiet=False, deprecated=False):
 
         self.mod = mod
         self.title = title
@@ -51,6 +51,7 @@ class Module(object):
         log.set_module(mod)
         self.args = []
         self.quiet = quiet
+        self.deprecated = deprecated
         self.lock_file = None
         self.help_only_support = False
         prop.prog = sys.argv[0]
@@ -78,6 +79,10 @@ class Module(object):
             self.installed_ui_toolkits.append(UI_TOOLKIT_QT4)
             self.num_installed_ui_toolkits += 1
 
+        if utils.to_bool(sys_conf.get('configure', 'qt5', '0')):
+            self.installed_ui_toolkits.append(UI_TOOLKIT_QT5)
+            self.num_installed_ui_toolkits += 1
+
         self.default_mode = INTERACTIVE_MODE
 
         self.num_valid_modes = 0
@@ -108,8 +113,8 @@ class Module(object):
                 self.default_ui_toolkit = 'none'
 
             elif (UI_TOOLKIT_QT4 in self.supported_ui_toolkits and self.default_ui_toolkit == 'qt4' and UI_TOOLKIT_QT4 in self.installed_ui_toolkits) or \
-                 (UI_TOOLKIT_QT3 in self.supported_ui_toolkits and self.default_ui_toolkit == 'qt3' and UI_TOOLKIT_QT3 in self.installed_ui_toolkits):
-
+                 (UI_TOOLKIT_QT3 in self.supported_ui_toolkits and self.default_ui_toolkit == 'qt3' and UI_TOOLKIT_QT3 in self.installed_ui_toolkits) or \
+                 (UI_TOOLKIT_QT5 in self.supported_ui_toolkits and self.default_ui_toolkit == 'qt5' and UI_TOOLKIT_QT5 in self.installed_ui_toolkits):
                 self.default_mode = GUI_MODE
 
             elif self.default_ui_toolkit == 'qt3' and UI_TOOLKIT_QT3 not in self.supported_ui_toolkits:
@@ -117,6 +122,9 @@ class Module(object):
                 if UI_TOOLKIT_QT4 in self.supported_ui_toolkits and UI_TOOLKIT_QT4 in self.installed_ui_toolkits: # (e.g, hp-linefeedcal?)
                     self.default_ui_toolkit = 'qt4'
                     self.default_mode = GUI_MODE
+                if UI_TOOLKIT_QT5 in self.supported_ui_toolkits and UI_TOOLKIT_QT5 in self.installed_ui_toolkits:
+                    self.default_ui_toolkit = 'qt5'
+                    self.default_mode = GUI_MODE
 
                 elif INTERACTIVE_MODE in self.avail_modes:
                     self.default_mode = INTERACTIVE_MODE
@@ -204,6 +212,10 @@ class Module(object):
             if UI_TOOLKIT_QT4 in self.supported_ui_toolkits and UI_TOOLKIT_QT4 in self.installed_ui_toolkits:
                 content.append(utils.USAGE_USE_QT4)
 
+            if UI_TOOLKIT_QT5 in self.supported_ui_toolkits and UI_TOOLKIT_QT5 in self.installed_ui_toolkits:
+                content.append(utils.USAGE_USE_QT5)
+                
+
         content.append(utils.USAGE_LOGGING1)
         content.append(utils.USAGE_LOGGING2)
         if include_flags & USAGE_FLAG_SUPRESS_G_DEBUG_FLAG != USAGE_FLAG_SUPRESS_G_DEBUG_FLAG:
@@ -288,6 +300,9 @@ class Module(object):
 
             if UI_TOOLKIT_QT4 in self.supported_ui_toolkits and UI_TOOLKIT_QT4 in self.installed_ui_toolkits:
                 long_params.extend(['qt4', 'use-qt4'])
+            
+            if UI_TOOLKIT_QT5 in self.supported_ui_toolkits and UI_TOOLKIT_QT5 in self.installed_ui_toolkits:
+                long_params.extend(['qt5', 'use-qt5'])
 
         if extra_params is not None:
             params = ''.join([params, extra_params])
@@ -299,6 +314,7 @@ class Module(object):
         show_usage = None
         device_uri = None
         printer_name = None
+        uiscan=False
         error_msg = []
         mode = self.default_mode
         if prop.gui_build:
@@ -356,6 +372,9 @@ class Module(object):
 
                 elif o == '--help-desc':
                     show_usage = 'desc'
+                
+                elif o == '--uiscan':
+                    uiscan = True
 
                 elif o in ('--qt3', '--use-qt3'):
                     if self.avail_modes is not None and GUI_MODE in self.avail_modes:
@@ -378,6 +397,18 @@ class Module(object):
                             ui_toolkit = 'qt4'
                         else:
                             error_msg.append("%s does not support Qt4. Unable to enter GUI mode." % self.mod)
+ 
+                elif o in ('--qt5', '--use-qt5'):
+                    if self.avail_modes is not None and GUI_MODE in self.avail_modes:
+                        if self.supported_ui_toolkits is not None and \
+                            UI_TOOLKIT_QT5 in self.supported_ui_toolkits and prop.gui_build and \
+                            UI_TOOLKIT_QT5 in self.installed_ui_toolkits:
+
+                            mode = GUI_MODE
+                            ui_toolkit = 'qt5'
+                        else:
+                            error_msg.append("%s does not support Qt4. Unable to enter GUI mode." % self.mod)
+               
 
                 #elif o in ('--lang', '--loc'):
                 #    if a.strip() == '?':
@@ -392,12 +423,14 @@ class Module(object):
 
         if self.help_only_support:
             if show_usage or error_msg:
-                self.usage(show_usage, error_msg)
+                if uiscan == False:
+                    self.usage(show_usage, error_msg)
             else:
                 log.info(log.bold("\nPlease check usage '%s --help'"%self.mod))
                 show_usage = 'text'
         else:
-            self.usage(show_usage, error_msg)
+            if uiscan == False:
+                self.usage(show_usage, error_msg)
 
         if show_usage is not None:
             sys.exit(0)
@@ -448,17 +481,23 @@ class Module(object):
             log.info("")
 
             if show_ver:
-                log.info(log.bold("HP Linux Imaging and Printing System (ver. %s)" % prop.version))
+                #if uiscan == False:
+                 log.info(log.bold("HP Linux Imaging and Printing System (ver. %s)" % prop.version))
             else:
-                log.info(log.bold("HP Linux Imaging and Printing System"))
+                #if uiscan == False:
+                 log.info(log.bold("HP Linux Imaging and Printing System"))
 
+            #if uiscan == False:
             log.info(log.bold("%s ver. %s" % (self.title, self.version)))
             log.info("")
-            log.info("Copyright (c) 2001-15 Hewlett-Packard Development Company, LP")
+            log.info("Copyright (c) 2001-18 HP Development Company, LP")
             log.info("This software comes with ABSOLUTELY NO WARRANTY.")
             log.info("This is free software, and you are welcome to distribute it")
             log.info("under certain conditions. See COPYING file for more details.")
             log.info("")
+            if self.deprecated:
+                log.warn(log.bold("%s support is deprecated. Feature can be used as is. Fixes or updates will not be provided" %self.title))
+                log.info("")
 
 
     def getDeviceUri(self, device_uri=None, printer_name=None, back_end_filter=device.DEFAULT_BE_FILTER,
@@ -546,7 +585,6 @@ class Module(object):
 
         elif len(devices) == 1: # Nothing specified, and only 1 device avail.
             device_uri_ret = list(devices.keys())[0]
-            log.info("Using device: %s\n" % device_uri_ret)
 
         if device_uri_ret is None and len(devices):
             if self.mode == INTERACTIVE_MODE:
@@ -647,7 +685,6 @@ class Module(object):
 
         elif len(printers) == 1: # nothing specified, and only 1 avail. printer
             printer_name_ret = printers[0]
-            log.info("Using printer: %s\n" % printer_name_ret)
 
         if printer_name_ret is None and self.mode in (INTERACTIVE_MODE, NON_INTERACTIVE_MODE) and len(printers):
             printer_name_ret = tui.printer_table(printers)
