@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2001-2009 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2001-2015 HP Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,17 +19,18 @@
 # Authors: Don Welch
 
 # Std Lib
+import signal
 
 # Local
 from base.g import *
 from base.codes import *
 from base import utils, device
 from prnt import cups
-from ui_utils import load_pixmap
+from .ui_utils import load_pixmap
 
 # Qt
 from qt import *
-from scrollprint import ScrollPrintView
+from .scrollprint import ScrollPrintView
 
 
 
@@ -47,6 +48,7 @@ class PrinterForm(QMainWindow):
         self.statusBar()
 
         self.setIcon(load_pixmap('hp_logo', '128x128'))
+        signal.signal(signal.SIGINT, signal.SIG_DFL)
 
         if not name:
             self.setName("PrinterForm")
@@ -82,7 +84,7 @@ class PrinterForm(QMainWindow):
                 max_deviceid_size = max(len(d), max_deviceid_size)
 
             if x == 0:
-                from nodevicesform import NoDevicesForm
+                from .nodevicesform import NoDevicesForm
                 self.FailureUI(self.__tr("<p><b>No devices found.</b><p>Please make sure your device is properly installed and try again."))
                 self.init_failed = True
 
@@ -91,7 +93,7 @@ class PrinterForm(QMainWindow):
                 self.device_uri = devices[0][0]
 
             else:
-                from chooseprinterdlg import ChoosePrinterDlg
+                from .chooseprinterdlg import ChoosePrinterDlg
                 dlg = ChoosePrinterDlg(self.cups_printers)
                 if dlg.exec_loop() == QDialog.Accepted:
                     self.printer_name = dlg.printer_name
@@ -116,7 +118,7 @@ class PrinterForm(QMainWindow):
             try:
                 self.cur_device = device.Device(device_uri=self.device_uri,
                                                  printer_name=self.printer_name)
-            except Error, e:
+            except Error as e:
                 log.error("Invalid device URI or printer name.")
                 self.FailureUI("<b>Invalid device URI or printer name.</b><p>Please check the parameters to hp-print and try again.")
                 self.init_failed = True
@@ -130,7 +132,7 @@ class PrinterForm(QMainWindow):
                 self.statusBar().message(self.device_uri)
 
         QTimer.singleShot(0, self.InitialUpdate)
-
+        
 
     def InitialUpdate(self):
         if self.init_failed:
@@ -148,7 +150,7 @@ class PrinterForm(QMainWindow):
 
 
     def FailureUI(self, error_text):
-        log.error(unicode(error_text).replace("<b>", "").replace("</b>", "").replace("<p>", " "))
+        log.error(str(error_text).replace("<b>", "").replace("</b>", "").replace("<p>", " "))
         QMessageBox.critical(self,
                              self.caption(),
                              error_text,
